export declare type ListJobsResponse = {
    items: Job[];
    apiVersion: string;
    kind: string;
    metadata: ListMeta;
    unreachable: string[];
};
export declare type Job = {
    apiVersion?: string;
    kind?: string;
    metadata?: ObjectMeta;
    spec?: JobSpec;
    status?: JobStatus;
};
export declare type ObjectMeta = {
    name: string;
    namespace?: string;
    selfLink?: string;
    uid?: string;
    resourceVersion?: string;
    generation?: number;
    creationTimestamp?: string;
    labels?: object;
    annotations?: object;
    deletionTimestamp?: string;
};
export declare type JobSpec = {
    template?: ExecutionTemplateSpec;
};
export declare type ExecutionTemplateSpec = {
    metadata?: ObjectMeta;
    spec: ExecutionSpec;
};
export declare type ExecutionSpec = {
    parallelism?: number;
    taskCount?: number;
    template?: TaskTemplateSpec;
};
export declare type TaskTemplateSpec = {
    spec?: TaskSpec;
};
export declare type TaskSpec = {
    volumes?: Volume[];
    containers?: Container[];
    timeoutSeconds?: string;
    serviceAccountName?: string;
    maxRetries?: number;
};
export declare type Volume = {
    name: string;
    secret: SecretVolumeSource;
};
export declare type SecretVolumeSource = {
    secretName: string;
    items: KeyToPath[];
    defaultMode: number;
};
export declare type KeyToPath = {
    key: string;
    path: string;
    mode?: number;
};
export declare type Container = {
    name: string;
    image: string;
    command?: string[];
    args?: string[];
    env?: EnvVar[];
    resources?: ResourceRequirements;
    workingDir?: string;
    ports?: ContainerPort[];
    volumeMounts?: VolumeMount[];
    livenessProbe?: Probe;
    startupProbe?: Probe;
    terminationMessagePath?: string;
    terminationMessagePolicy?: string;
    imagePullPolicy?: string;
};
export declare type EnvVar = {
    name: string;
    value?: string;
    valueFrom?: EnvVarSource;
};
export declare type EnvVarSource = {
    secretKeyRef: SecretKeySelector;
};
export declare type SecretKeySelector = {
    key: string;
    optional?: boolean;
    name?: string;
};
export declare type ResourceRequirements = {
    limits?: object;
    requests?: object;
};
export declare type ContainerPort = {
    name?: string;
    containerPort?: number;
    protocol?: string;
};
export declare type VolumeMount = {
    name: string;
    readOnly?: boolean;
    mountPath: string;
    subPath?: string;
};
export declare type Probe = {
    initialDelaySeconds?: number;
    timeoutSeconds?: number;
    periodSeconds?: number;
    successThreshold?: number;
    failureThreshold?: number;
    httpGet?: HTTPGetAction;
    tcpSocket?: TCPSocketAction;
    grpc?: GRPCAction;
};
export declare type HTTPGetAction = {
    path?: string;
    httpHeaders?: HTTPHeader[];
};
export declare type HTTPHeader = {
    name: string;
    value?: string;
};
export declare type TCPSocketAction = {
    port?: number;
};
export declare type GRPCAction = {
    port?: number;
    service?: string;
};
export declare type ListMeta = {
    selfLink: string;
    resourceVersion: string;
    continue?: string;
};
export declare type JobStatus = {
    observedGeneration?: number;
    conditions?: Condition[];
    executionCount?: number;
    latestCreatedExecution?: ExecutionReference;
};
export declare type Condition = {
    type: string;
    status: string;
    reason?: string;
    message?: string;
    lastTransitionTime?: string;
    severity?: string;
};
export declare type ExecutionReference = {
    name?: string;
    creationTimestamp?: string;
    completionTimestamp?: string;
};
